@@ -60,9 +60,9 @@ class ManageConsumers():
         # Failing to connect exception
         except Exception as err:
             # Logging exceptions
-            _logger.error(f'Error processing job {err}')
+            _logger.error(f'Could Not Establish Connection, Retrying in 5 Seconds...')
             # waiting for 10 seconds to try top recconnect to Rabit MQ server
-            time.sleep(10)
+            time.sleep(5)
             # Calling connect function to retry connecting to the server
             self.connect()
             
@@ -98,9 +98,12 @@ class ManageConsumers():
         channel.basic_ack(delivery_tag=method.delivery_tag)
 
     def start_consume(self):
-        # Binding the qeue to a specific exchange
-        self._channel.queue_bind(exchange=self.exchange_name, queue=self.qeue_name, routing_key=self.new_jobs_routing_key)
-        # Setting the consuming call back function
-        self._channel.basic_consume(self.qeue_name, self.handle_new_message)
-        # Starting consuming from the queue 
-        self._channel.start_consuming()
\ No newline at end of file
+        if not self._channel.connection:
+            self.connect()
+        else: 
+            # Binding the qeue to a specific exchange
+            self._channel.queue_bind(exchange=self.exchange_name, queue=self.qeue_name, routing_key=self.new_jobs_routing_key)
+            # Setting the consuming call back function
+            self._channel.basic_consume(self.qeue_name, self.handle_new_message)
+            # Starting consuming from the queue 
+            self._channel.start_consuming()
\ No newline at end of file
